class RPSHandler {
    constructor() {
        this.moves = ["rock", "paper", "scissors"];
        this.playerMove = null;
        this.computerMove = null;
        this.infoDiv = document.getElementById("info-div");
        this.resultDiv = document.getElementById("result-message");
        this.computerChoiceDiv = document.getElementById("computer-choice");
        this.setupEventListeners();
    }

    setupEventListeners() {
        // Register mouseover and mouseout events for images
        this.moves.forEach(move => {
            const img = document.getElementById(`${move}-img`);
            img.addEventListener("mouseover", () => this.showInfo(move));
            img.addEventListener("mouseout", () => this.hideInfo());
        });

        // Register click events for buttons
        this.moves.forEach(move => {
            const btn = document.getElementById(`${move}-btn`);
            btn.addEventListener("click", () => this.makeMove(move));
        });
    }

    showInfo(move) {
        const beats = {
            rock: "scissors",
            paper: "rock",
            scissors: "paper"
        };
        this.infoDiv.innerText = `${move} beats ${beats[move]}`;
        this.infoDiv.style.display = "block";
    }

    hideInfo() {
        this.infoDiv.style.display = "none";
    }

    makeMove(move) {
        this.playerMove = move;
        this.computerMove = this.moves[Math.floor(Math.random() * 3)];
        this.computerChoiceDiv.innerText = this.computerMove.charAt(0).toUpperCase() + this.computerMove.slice(1);
        this.displayResult();
    }

    displayResult() {
        let result;
        if (this.playerMove === this.computerMove) {
            result = "It's a draw!";
        } else if (
            (this.playerMove === "rock" && this.computerMove === "scissors") ||
            (this.playerMove === "paper" && this.computerMove === "rock") ||
            (this.playerMove === "scissors" && this.computerMove === "paper")
        ) {
            result = "You win!";
        } else {
            result = "You lose!";
        }
        this.resultDiv.innerText = `You chose ${this.playerMove}, Computer chose ${this.computerMove}. ${result}`;
    }

    resetGame() {
        this.playerMove = null;
        this.computerMove = null;
        this.resultDiv.innerText = "";
        this.computerChoiceDiv.innerText = "?";
        this.infoDiv.style.display = "none";
    }
}

// Instantiate the RPSHandler only once
const rpsHandler = new RPSHandler();
